smartcard.reader.ReaderGroups.BadReaderGroupException

# ``smartcard`.`reader`.`ReaderGroups`.`BadReaderGroupException``

exception documentation

`class BadReaderGroupException(SmartcardException):`

View In Hierarchy

Raised when trying to add an invalid reader group.

Method | `__init__` | Undocumented

Inherited from `SmartcardException`:

Method | `__str__` | Undocumented
Instance Variable | `hresult` | Undocumented

def __init__(self):
overrides `smartcard.Exceptions.SmartcardException.__init__`

Undocumented